@@ -213,8 +213,8 @@ When only `add-text-properties' is available APPEND is ignored."
                                   if (member f old-to-rename)
                                   collect (assoc-default f files-renamed)
                                   else collect f))))
-	  ;; Re-sort the buffer.
-	  (revert-buffer)
+	  ;; Re-sort the buffer if all went well.
+	  (unless (> errors 0) (revert-buffer))
 	  (let ((inhibit-read-only t))
 	    (dired-mark-remembered wdired-old-marks)))
       (let ((inhibit-read-only t))
@@ -893,6 +893,34 @@ of this function is really needed."
       ;; Restart from beginning until string is completely decoded.
       (goto-char (point-min)))
     (decode-coding-string (buffer-string) 'utf-8)))
+
+(defun helm-read-answer (prompt answer-list)
+  "Prompt user for an answer.
+Arg PROMPT is the prompt to present user the different possible
+answers, ANSWER-LIST is a list of strings.
+If user enter an answer which is one of ANSWER-LIST return this
+answer, otherwise keep prompting for a valid answer.
+Note that answer should be a single char, only short answer are
+accepted.
+
+Example:
+
+    (let ((answer (helm-read-answer
+                    \"answer [y,n,!,q]: \"
+                    '(\"y\" \"n\" \"!\" \"q\"))))
+      (pcase answer
+          (\"y\" \"yes\")
+          (\"n\" \"no\")
+          (\"!\" \"all\")
+          (\"q\" \"quit\")))
+
+"
+  (helm-awhile (string
+                (read-key (propertize prompt 'face 'minibuffer-prompt)))
+    (if (member it answer-list)
+        (cl-return it)
+      (message "Please answer by %s" (mapconcat 'identity answer-list ", "))
+      (sit-for 1))))
 
 ;;; Symbols routines
 ;;
