@@ -47,7 +47,12 @@
     (find-file . nil)
     (find-file-at-point . helm-completing-read-sync-default-handler)
     (ffap . helm-completing-read-sync-default-handler)
-    (execute-extended-command . nil))
+    (execute-extended-command . nil)
+    (dired-do-rename . helm-read-file-name-handler-1)
+    (dired-do-copy . helm-read-file-name-handler-1)
+    (dired-do-symlink . helm-read-file-name-handler-1)
+    (dired-do-relsymlink . helm-read-file-name-handler-1)
+    (dired-do-hardlink . helm-read-file-name-handler-1))
   "Completing read functions for specific Emacs commands.
 
 By default `helm-mode' use `helm-completing-read-default-handler' to
@@ -343,17 +348,21 @@ If COLLECTION is an `obarray', a TEST should be needed. See `obarray'."
       (setq candidates (append (list
                                 ;; Unquote helm-pattern
                                 ;; when it is added
-                                ;; as candidate.
-                                (replace-regexp-in-string
-                                 "\\s\\" "" helm-pattern))
+                                ;; as candidate: Why? #2015
+                                ;; (replace-regexp-in-string
+                                ;;  "\\s\\" "" helm-pattern)
+                                helm-pattern)
                                candidates))
       ;; Notify pattern have been added to candidates.
       (setq unknown-pattern t))
     (cl-loop for c in candidates
              for cand = (if (stringp c)
-                            (replace-regexp-in-string "\\s\\" "" c) c)
+                            (replace-regexp-in-string "\\s\\" "" c)
+                          c)
              for pat = (replace-regexp-in-string "\\s\\" "" helm-pattern)
-             if (and (equal c pat) unknown-pattern) collect
+             if (and (or (equal c pat) (equal c helm-pattern))
+                     unknown-pattern)
+             collect
              (cons (concat (propertize
                             " " 'display
                             (propertize "[?]" 'face 'helm-ff-prefix))
@@ -639,6 +648,7 @@ that use `helm-comp-read' See `helm-M-x' for example."
                          :preselect preselect
                          :prompt prompt
                          :resume 'noresume
+                         :keymap loc-map ;; Needed with empty collection.
                          :allow-nest allow-nest
                          :candidate-number-limit candidate-number-limit
                          :case-fold-search case-fold
@@ -837,7 +847,16 @@ See documentation of `completing-read' and `all-completions' for details."
                    collect h))
          ;; Disable hack that could be used before `completing-read'.
          ;; i.e (push ?\t unread-command-events).
-         unread-command-events)
+         unread-command-events
+         (default-handler
+          ;; Typically when COLLECTION is a function, we can assume
+          ;; the intention is completing dynamically according to
+          ;; input; If one want to use in-buffer handler for specific
+          ;; usage with a function as collection he can specify it in
+          ;; helm-completing-read-handlers-alist.
+          (if (functionp collection)
+              #'helm-completing-read-sync-default-handler
+            #'helm-completing-read-default-handler)))
     (when (eq def-com 'ido) (setq def-com 'ido-completing-read))
     (unless (or (not entry) def-com)
       ;; An entry in *read-handlers-alist exists but have
@@ -872,13 +891,13 @@ See documentation of `completing-read' and `all-completions' for details."
                 ;; If we are here `helm-mode' is now disabled.
                 def-com
                 (apply def-com def-args))
-               (;; Use by default a cands-in-buffer handler which
-                ;; should work everywhere, it is much faster. 
+               (;; Use by default a in-buffer handler unless
+                ;; COLLECTION is a function. 
                 t
-                (helm-completing-read-default-handler
-                 prompt collection predicate require-match
-                 initial-input hist def inherit-input-method
-                 str-command buf-name)))
+                (funcall default-handler
+                         prompt collection predicate require-match
+                         initial-input hist def inherit-input-method
+                         str-command buf-name)))
       (helm-mode 1)
       ;; When exiting minibuffer, `this-command' is set to
       ;; `helm-exit-minibuffer', which is unwanted when starting
@@ -1025,6 +1044,7 @@ Keys description:
              :candidates
              (lambda ()
                (append (and (not (file-exists-p helm-pattern))
+                            (not (helm-ff--invalid-tramp-name-p helm-pattern))
                             (list helm-pattern))
                        (if test
                            (cl-loop with hn = (helm-ff--tramp-hostnames)
@@ -1100,6 +1120,7 @@ Don't use it directly, use instead `helm-read-file-name' in your programs."
                       helm-completing-read-handlers-alist))
          (def-com  (cdr-safe entry))
          (str-defcom (and def-com (helm-symbol-name def-com)))
+         ;; Don't modify the original args list for emacs generic functions.
          (def-args (list prompt dir default-filename mustmatch initial predicate))
          ;; Append the two extra args needed to set the buffer and source name
          ;; in helm specialized functions.
@@ -1140,7 +1161,11 @@ Don't use it directly, use instead `helm-read-file-name' in your programs."
     (unwind-protect
          (setq fname
                (cond (;; A specialized function exists, run it
-                      ;; with the two extra args specific to helm..
+                      ;; with the two extra args specific to helm.
+                      ;; Note that the helm handler should ensure
+                      ;; :initial-input is not nil i.e. Use init
+                      ;; which fallback to default-directory instead
+                      ;; of INITIAL.
                       (and def-com helm-mode
                            (not (eq def-com 'ido-read-file-name))
                            (not (eq def-com 'incompatible)))
@@ -1160,6 +1185,7 @@ Don't use it directly, use instead `helm-read-file-name' in your programs."
                        :name str-command
                        :buffer buf-name
                        :default default-filename
+                       ;; Helm handlers should always have a non nil INITIAL arg.
                        :initial-input (expand-file-name init dir)
                        :alistp nil
                        :must-match mustmatch
@@ -1184,16 +1210,24 @@ Don't use it directly, use instead `helm-read-file-name' in your programs."
 Can be added to `helm-completing-read-handlers-alist' for functions
 that need a `read-file-name' function with directory history.
 The `helm-find-files' history `helm-ff-history' is used here."
-  (helm-read-file-name
-   prompt
-   :name name
-   :history helm-ff-history
-   :buffer buffer
-   :default default-filename
-   :initial-input (expand-file-name initial dir)
-   :alistp nil
-   :must-match mustmatch
-   :test predicate))
+  (let ((helm-always-two-windows t)
+        (helm-split-window-default-side
+         (if (eq helm-split-window-default-side 'same)
+             'below helm-split-window-default-side))
+        helm-split-window-inside-p
+        helm-reuse-last-window-split-state
+        ;; Helm handlers should always have a non nil INITIAL arg.
+        (init (or initial dir default-directory)))
+    (helm-read-file-name
+     prompt
+     :name name
+     :history helm-ff-history
+     :buffer buffer
+     :default default-filename
+     :initial-input (expand-file-name init dir)
+     :alistp nil
+     :must-match mustmatch
+     :test predicate)))
 
 
 ;;; Completion in region
