@@ -180,7 +180,7 @@ This affect also sorting functions in the same way."
                (remove-hook 'post-command-hook 'helm-top-poll-no-update)
                (remove-hook 'focus-in-hook 'helm-top-poll-no-update))
     :display-to-real #'helm-top-display-to-real
-    :persistent-action #'helm-top-sh-persistent-action
+    :persistent-action '(helm-top-sh-persistent-action . never-split)
     :persistent-help "SIGTERM"
     :help-message 'helm-top-help-message
     :mode-line 'helm-top-mode-line
@@ -250,7 +250,6 @@ Show actions only on line starting by a PID."
                   "kill" nil nil nil (format "-%s" sig) pids)))
 
 (defun helm-top-sh-persistent-action (pid)
-  (delete-other-windows)
   (helm-top-sh "TERM" (list pid))
   (helm-delete-current-selection))
 
